@@ -2,7 +2,7 @@ package Yars::Command::yars_fast_balance;
 
 # PODNAME: yars_fast_balance
 # ABSTRACT: Fix all files
-our $VERSION = '0.90'; # VERSION
+our $VERSION = '0.91'; # VERSION
 
 
 use strict;
@@ -14,7 +14,6 @@ use Clustericious::Log;
 use Clustericious::Config;
 use Hash::MoreUtils qw/safe_reverse/;
 use File::Find::Rule;
-use IO::Dir;
 use Fcntl qw(:DEFAULT :flock);
 use Data::Dumper;
 use File::Basename qw/dirname/;
@@ -26,9 +25,10 @@ our $yc = Yars::Client->new();
 sub _is_empty_dir {
   # http://www.perlmonks.org/?node_id=617410
   my ($shortname, $path, $fullname) = @_;
-  my $dh = IO::Dir->new($fullname) or return;
-  my $count = scalar(grep{!/^\.\.?$/} $dh->read());
-  $dh->close();
+  my $dh;
+  opendir($dh, $fullname) || return;
+  my $count = scalar(grep{!/^\.\.?$/} readdir $dh);
+  closedir $dh;
   return($count==0);
 }
 
